export interface IceServerProperties {
    /**
     * Set the url for the ICE Server you want to use.
     * It should follow a valid format:
     *
     * - [https://datatracker.ietf.org/doc/html/rfc7065#section-3.1](https://datatracker.ietf.org/doc/html/rfc7065#section-3.1)
     * - [https://datatracker.ietf.org/doc/html/rfc7064#section-3.1](https://datatracker.ietf.org/doc/html/rfc7064#section-3.1)
     *
     */
    url: string;
    /**
     * Secret for TURN authentication based on:
     *  - [https://tools.ietf.org/html/draft-uberti-behave-turn-rest-00](https://tools.ietf.org/html/draft-uberti-behave-turn-rest-00)
     *  - [https://www.ietf.org/proceedings/87/slides/slides-87-behave-10.pdf](https://www.ietf.org/proceedings/87/slides/slides-87-behave-10.pdf)
     * This will generate credentials valid for 24 hours which is the recommended value
     */
    staticAuthSecret?: string;
    /**
     * Set a username for the ICE Server you want to use.
     * This parameter should be defined only for TURN, not for STUN ICE Servers.
     */
    username?: string;
    /**
     * Set a credential for the ICE Server you want to use.
     * This parameter should be defined only for TURN, not for STUN ICE Servers.
     */
    credential?: string;
}
